@@ -26,9 +26,14 @@ from PyQt4.QtGui import *
 import ConfigParser
 import os, os.path
 
+import dbus
+from dbus.mainloop.qt import DBusQtMainLoop
+
 import records #record data
 import data #own data
 
+
+
 #own functions
 from functions_general import *
 from functions_file import *
@@ -40,6 +45,7 @@ from Ui_StartWindow import *
 from Ui_RecordWindow import *
 from Ui_ViewWindow import *
 from Ui_ConfigWindow import *
+from Ui_HelpWindow import *
 from Ui_DateWindow import *
 from Ui_AlarmTimeWindow import *
 from Ui_AskForKeepWindow import *
@@ -53,7 +59,7 @@ from Ui_AdditionalInfoWindow import *
 ## Main function
 ###########################################################################
 def main():
-    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow,  AlarmTimeWindow,  AskForKeepWindow,  AdditionalInfoWindow
+    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow,  AlarmTimeWindow,  AskForKeepWindow,  AdditionalInfoWindow,  HelpWindow
     global config
     global RecordWindowGraph
    
@@ -99,6 +105,7 @@ def main():
     RecordWindow = frmRecordWindow(StartWindow)
     ConfigWindow = frmConfigWindow(StartWindow)
     ViewWindow = frmViewWindow(StartWindow)
+    HelpWindow = frmHelpWindow(StartWindow)
     AlarmTimeWindow = frmAlarmTimeWindow(StartWindow)
     DateWindow = frmDateWindow(ViewWindow)
     AdditionalInfoWindow = frmAdditionalInfoWindow(ViewWindow)
@@ -117,6 +124,9 @@ def main():
     if(data.user==""):
         EditUserName()
 
+
+    DisplayStatusDaemon()
+    
     sys.exit(app.exec_())
 
 
@@ -128,14 +138,17 @@ def main():
 ## 
 ###########################################################################
 def EditUserName():
-    text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
+#      r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
+#        if(r[1]==True): #OK pressed
+    r = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
      "It will be used in the records file, this makes it easier\n" + \
      "when you want to share your sleep pattern with others.", 0,  data.user)
-#    if(text != ""):
-    data.user=unicode(text[0])
-    config.set('main', 'user', str(data.user.encode( "utf-8" )))    
-#    else:
-#        pass
+#    if(r != ""):
+    if(r[1]==True): #OK pressed
+        data.user=unicode(r[0])
+        if(data.user==""): data.user="-"
+        config.set('main', 'user', str(data.user.encode( "utf-8" )))  
+        
     print "User name:",  data.user
 
 
@@ -213,36 +226,37 @@ def InitMeasurement():
 #    data.interval=1 #Debugging
     
     #change to offline mode and silent profile if requested
-    if(data.QuickMode==False):
-        if(data.OfflineMode==True): #change to offline mode
-            try:
-                cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
-                ret=os.popen2(cmd) #get current mode
-                p=ret[1].readline() #not used
-                p=ret[1].readline()
-                tmp=string.split(p,  "\"")
-                data.PreviousMode=tmp[1]
-                if(data.PreviousMode=="normal"): #was normal, change to offline
-                    cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
-                    os.popen(cmd)
-            except:
-                pass
-                
-        if(data.SilentProfile==True): #change to silent profile
-            try:
-                cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
-                ret=os.popen2(cmd) #get current profile
-                p=ret[1].readline() #not used
-                p=ret[1].readline()
-                tmp=string.split(p,  "\"")
-                data.PreviousProfile=tmp[1]
-                if(data.PreviousProfile=="general"): #was general, change to silent
-                    cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
-                    os.popen(cmd)
-                    cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Silent Profile activated\""
-                    os.popen(cmd)
-            except:
-                pass   
+    if(data.demo==False): #We are on a N900
+        if(data.QuickMode==False):
+            if(data.OfflineMode==True): #change to offline mode
+                try:
+                    cmd="dbus-send --system --dest=com.nokia.mce --print-reply --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode"
+                    ret=os.popen2(cmd) #get current mode
+                    p=ret[1].readline() #not used
+                    p=ret[1].readline()
+                    tmp=string.split(p,  "\"")
+                    data.PreviousMode=tmp[1]
+                    if(data.PreviousMode=="normal"): #was normal, change to offline
+                        cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
+                        os.popen(cmd)
+                except:
+                    pass
+                    
+            if(data.SilentProfile==True): #change to silent profile
+                try:
+                    cmd="dbus-send --type=method_call --print-reply --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.get_profile"
+                    ret=os.popen2(cmd) #get current profile
+                    p=ret[1].readline() #not used
+                    p=ret[1].readline()
+                    tmp=string.split(p,  "\"")
+                    data.PreviousProfile=tmp[1]
+                    if(data.PreviousProfile=="general"): #was general, change to silent
+                        cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
+                        os.popen(cmd)
+                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Silent Profile activated\""
+                        os.popen(cmd)
+                except:
+                    pass   
 
     data.run=True #change to recording
     app.timer_GetData = QtCore.QTimer()
@@ -295,24 +309,25 @@ def StopMeasurement():
 
     data.run=False
 
-    #change back to nromal mode and general profile if requested
-    if(data.QuickMode==False): #normal mode
-        if(data.OfflineMode==True and data.demo!=1): #change to offline mode
-            try:
-                if(data.PreviousMode=="normal"): #was normal (before start measurement), so restore to normal
-                    cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
-                    os.popen(cmd)
-            except:
-                pass
-        if(data.SilentProfile==True and data.demo!=1): #change to offline mode
-            try:
-                if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
-                    cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
-                    os.popen(cmd)  #set profile              
-                    cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"General Profile activated\""
-                    os.popen(cmd)  #notification
-            except:
-                pass
+    #change back to normal mode and general profile if requested
+    if(data.demo==False): #We are on a N900
+        if(data.QuickMode==False): #normal mode
+            if(data.OfflineMode==True and data.demo!=1): #change to offline mode
+                try:
+                    if(data.PreviousMode=="normal"): #was normal (before start measurement), so restore to normal
+                        cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
+                        os.popen(cmd)
+                except:
+                    pass
+            if(data.SilentProfile==True and data.demo!=1): #change to offline mode
+                try:
+                    if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
+                        cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
+                        os.popen(cmd)  #set profile              
+                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"General Profile activated\""
+                        os.popen(cmd)  #notification
+                except:
+                    pass
 
 
 
@@ -353,7 +368,7 @@ def MoveTrigger(direction):
 
 
 def About(ui):
-    QtGui.QMessageBox.about(ui, 'About SleepAnalyser', "Copyright 2010 by George Ruinelli\n"+\
+    QtGui.QMessageBox.about(ui, 'About SleepAnalyser', "Copyright 2010 by George Ruinelli with great support from the MAEMO community\n"+\
     "Version: "+str(data.version)+"-"+str(data.build)+"\n"+\
     "Contact: george@ruinelli.ch\nWebsite: https://garage.maemo.org/projects/sleepanalyser/\n"+\
     "\nFeedback and donations are very welcome!")
@@ -372,24 +387,30 @@ class frmStartWindow(QMainWindow):
         self.ui.setupUi(self)
 
         QtCore.QObject.connect(self.ui.bCollecting, QtCore.SIGNAL("clicked()"), self.StartMeasurementNormal)
-        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
+#        QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
-        QtCore.QObject.connect(self.ui.bConfig, QtCore.SIGNAL("clicked()"), self.ShowConfigWindow)
+#        QtCore.QObject.connect(self.ui.bConfig, QtCore.SIGNAL("clicked()"), self.ShowConfigWindow)
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
-        QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         
-        file = open(data.app_path+"Info.htm", 'r')
-        txt=""
-        for line in file: txt=txt+line+"\n"
-        file.close()
-        self.ui.textBrowser.setHtml(txt)
+        QtCore.QObject.connect(self.ui.actionTest_recording, QtCore.SIGNAL("triggered()"), self.StartMeasurementQuick)
+        QtCore.QObject.connect(self.ui.actionSettings, QtCore.SIGNAL("triggered()"), self.ShowConfigWindow)
+        QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
+        QtCore.QObject.connect(self.ui.actionHelp, QtCore.SIGNAL("triggered()"), self.ShowHelpWindow)
+
+        
+#        file = open(data.app_path+"Info.htm", 'r')
+#        txt=""
+#        for line in file: txt=txt+line+"\n"
+#        file.close()
+#        self.ui.textBrowser.setHtml(txt)
         
         if(data.app_path!="./"): #only needed if not started in app path
+            self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
-            self.ui.bQuick.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
+#            self.ui.bQuick.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
             self.ui.bCollecting.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
             self.ui.bLog.setIcon(QIcon(data.app_path+"img/"+"zoom.png"))
-            self.ui.bConfig.setIcon(QIcon(data.app_path+"img/"+"configure.png"))
+#            self.ui.bConfig.setIcon(QIcon(data.app_path+"img/"+"configure.png"))
 
 
 
@@ -428,7 +449,7 @@ class frmStartWindow(QMainWindow):
         
         
     ###########################################################################
-    # Show the log window (where the data from a file gets visualised)
+    ## Show the log window (where the data from a file gets visualised)
     ###########################################################################
     def ShowViewWindow(self):
         global ViewWindowGraph       ,  WidgetGraph
@@ -481,6 +502,19 @@ class frmStartWindow(QMainWindow):
         ConfigWindow.UpdateScreen()
         ConfigWindow.show()
 
+        
+        
+        
+        
+    def ShowHelpWindow(self):
+        HelpWindow.show()
+        #    cmd="dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:\"/opt/SleepAnalyser/Info.htm\""
+#        cmd="dbus-send --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser com.nokia.osso_browser.load_url string:\"/opt/SleepAnalyser/Info.htm\""
+#        ret=os.popen2(cmd) #get current mode
+
+
+
+
 
 
         
@@ -501,7 +535,7 @@ class frmStartWindow(QMainWindow):
             print "Application version:",  data.version,  "Build:",  data.build
         except:
             print "Version file not found"
-        self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
+#        self.ui.lblVersion.setText("Version: "+data.version+"-"+data.build)
 
 
     def About(self):
@@ -562,8 +596,8 @@ class frmRecordWindow(QMainWindow):
     def UpdateScreenStart(self):
 #        t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
         t=strftime("%a. %x %X", data.StartTime)
-        self.ui.lblStarttime.setText(t)
-        self.ui.lblElapsedTime.setText("")
+        self.ui.lblStarttime.setText("Start: "+t)
+        self.ui.lblElapsedTime.setText("Elapsed time:")
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
         self.ui.bStop.setText("Stop")
@@ -571,26 +605,31 @@ class frmRecordWindow(QMainWindow):
         if(records.AlarmIsSet==True): #alarm active
             m=str(data.AlarmMinute)
             if(len(m)==1): m="0"+m
-            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
+#            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
+            self.ui.lblAlarmTime.setText("Alarm time: "+strftime("%H:%M", records.AlarmTimeWindowStart_tuple)+" - "+strftime("%H:%M", records.AlarmTimeWindowEnd_tuple))
         else: #Do only recording, no alarm
-            self.ui.lblAlarmTime.setText("(No Alarm set)")
+            self.ui.lblAlarmTime.setText("Alarm time: (No Alarm set)")
                         
-        self.ui.lblNote.setText("")
+        self.ui.lblNote.setText("Note: ")
         self.UpdateScreen()
         
         
         
         
-    def UpdateScreen(self):
+    def UpdateScreen(self):    
+        if(data.DisplayIsOn==False):
+            if(data.debug==1): print "-> Do not update screen, Display is off!"
+            return
+            
         if(data.run==True): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
 #            d=time.strftime("%X", time.gmtime(time_difference))
             d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
-            self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries)")
+            self.ui.lblElapsedTime.setText("Elapsed time: "+d + " ("+str(records.Index)+" entries)")
         else: self.UpdateScreenStop()
         
-        self.ui.lblStatus.setText(data.Status)
+        self.ui.lblStatus.setText("Status: "+data.Status)
             
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -609,13 +648,7 @@ class frmRecordWindow(QMainWindow):
 
     def UpdateScreenStop(self):
         self.ui.bStop.setText("Close")
-#        t=time.mktime(time.localtime())
-#        time_difference=t-data.StartTimeSec
-##        d=time.strftime("%X", time.gmtime(time_difference))
-#        d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
-##        self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries, stopped)")
-#        self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries)")
-        self.ui.lblStatus.setText(data.Status)
+        self.ui.lblStatus.setText("Status: "+data.Status)
         
         
         
@@ -690,7 +723,7 @@ class frmRecordWindow(QMainWindow):
         r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
         if(r[1]==True): #OK pressed
             records.Note=unicode(r[0])
-            self.ui.lblNote.setText(records.Note)
+            self.ui.lblNote.setText("Note: "+records.Note)
             if(data.run==True): UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
 
@@ -752,7 +785,7 @@ class frmViewWindow(QMainWindow):
 #        shortfolder=string.replace(data.logfolder, data.homedir, "~/")
 #        shortfolder=string.replace(shortfolder, "//", "/") #workaround
 #        self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
-        self.ui.lblLogfile.setText(data.logfilename)
+        self.ui.lblLogfile.setText("Record: "+data.logfilename)
 
 #        d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
         d0=strftime("%a. %x %X", records.StartTime_tuple)
@@ -775,9 +808,9 @@ class frmViewWindow(QMainWindow):
         diff=time.strftime("%H:%M:%S", time.gmtime(diff_sec))
         if(diff_sec>86400): d="1 day, " #longer than 24h
         else: d=""
-        self.ui.lblTimes.setText(str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
+        self.ui.lblTimes.setText("Time: "+str(d0)+"  -  "+str(d1)+"  (Duration: "+d+str(diff)+")")
 
-        self.ui.lblNote.setText(records.Note)
+        self.ui.lblNote.setText("Note: "+records.Note)
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -1015,7 +1048,7 @@ class frmViewWindow(QMainWindow):
             tmp=r[0]
             tmp=unicode(tmp)
             records.Note=tmp
-            self.ui.lblNote.setText(records.Note)
+            self.ui.lblNote.setText("Note: "+records.Note)
             UpdateFileHeader() #rewrite log file (only do when recording is stopped!)
 
 
@@ -1042,6 +1075,31 @@ class frmViewWindow(QMainWindow):
 
 
 
+
+
+
+###########################################################################
+## Class for Help Window
+###########################################################################
+class frmHelpWindow(QMainWindow):
+    def __init__(self, parent):
+        QMainWindow.__init__(self, parent) # Notice that you must give a parent window as parameter to the constuctor
+        if(data.demo==False): self.setAttribute(Qt.WA_Maemo5StackedWindow) # Also set the Stacked Window parameter for every subwindow in the stack
+        
+        self.ui = Ui_HelpWindow()
+        self.ui.setupUi(self)
+      
+        file = open(data.app_path+"Info.htm", 'r')
+        txt=""
+        for line in file: txt=txt+line+"\n"
+        file.close()
+        self.ui.textBrowser.setHtml(txt)
+        
+
+
+
+
+
 ###########################################################################
 ## Class for Configuration Window
 ###########################################################################
@@ -1391,7 +1449,7 @@ class frmAskForKeepWindow(QMainWindow):
         
         self.ui = Ui_AskForKeepWindow()
         self.ui.setupUi(self)
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
 
         QtCore.QObject.connect(self.ui.bstop_keepRecord, QtCore.SIGNAL("clicked()"), self.KeepRecord)
         QtCore.QObject.connect(self.ui.bstop_removeRecord, QtCore.SIGNAL("clicked()"), self.RemoveRecord)
@@ -1407,10 +1465,11 @@ class frmAskForKeepWindow(QMainWindow):
     ## 
     ###########################################################################
     def UpdateScreen(self):
-        s="Do you really want to stop recording?"
-        if(records.AlarmIsSet==True): s=s+"\nThis will also remove the set alarm!"
-        s=s+"\n\nAnd do you want to keep the record?"
-        self.ui.lblNote.setText(s)
+#        s="Do you really want to stop recording?"
+#        if(records.AlarmIsSet==True): s=s+"\nThis will also remove the set alarm!"
+#        s=s+"\n\nAnd do you want to keep the record?"
+#        self.ui.lblNote.setText(s)
+        pass
         
 
     ###########################################################################
@@ -1462,7 +1521,6 @@ class frmAskForKeepWindow(QMainWindow):
     ###########################################################################
     def closeEvent(self, event):        
         event.ignore() #do not close
-
         self.KeepRecord() #interprete closing as "stop and keep file"
 
 
@@ -1475,6 +1533,62 @@ class frmAskForKeepWindow(QMainWindow):
 
 
 
+
+
+
+
+
+
+###########################################################################
+## 
+###########################################################################
+class DisplayStatusDaemon:
+    def __init__(self):
+        if(data.demo==False): #We are on a N900
+            loop = DBusQtMainLoop(set_as_default=True)
+            system_bus = dbus.SystemBus()
+            system_bus.add_signal_receiver(self.DisplayStatus,
+                                           path='/com/nokia/mce/signal',
+                                        signal_name='display_status_ind',
+                                        dbus_interface='com.nokia.mce.signal')
+            print "DisplayStatusDaemon started"
+
+
+
+
+    ###########################################################################
+    ## 
+    ###########################################################################
+    def DisplayStatus(self, *params):
+        global RecordWindowGraph 
+#        print "1", len(params)
+#        print params
+        tmp=str(params)
+        tmp=string.split(tmp, "'")
+#        print tmp
+        if(tmp[1]=="off"): data.DisplayIsOn=False
+        elif(tmp[1]=="on"): 
+            data.DisplayIsOn=True
+            if(data.run==True): 
+                if(data.debug==1): print "Update screen & graph"
+                RecordWindow.UpdateScreen()
+                data.ChangesInGraph=True
+                RecordWindowGraph.update()
+                
+
+        if(data.debug==1): print "DBUS Daemon => DisplayIsOn:",  data.DisplayIsOn
+        
+        
+        
+        
+        
+        
+        
+        
+
+
+
+
 ###########################################################################
 ## Class for drawing the RecordWindowGraph
 ###########################################################################
@@ -1508,6 +1622,7 @@ class ViewWindowCanvas(QtGui.QWidget):
 
     
     
+
     
     
 ###########################################################################
