@@ -1,15 +1,13 @@
-﻿#Global variables
-
+﻿###########################################################################
+## All global variables in here are data either saved or loaded for/from a record file
+###########################################################################
 
 MaxArrayDataLen=8640 #(1 value/10sec for 24h), 6*24*60
 
-
 #             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
 arrData=[[0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen,        [0]*MaxArrayDataLen ,             [0]*MaxArrayDataLen]  
 
-
 Index=-1
-
 LastIndex=-1 #maximum from Index and AlarmTimeWindowEnd index
 
 StartTime_tuple=-1
@@ -18,28 +16,25 @@ StartTime_seconds=-1
 AlarmTime_tuple=-1
 AlarmTime_seconds=-1
 
+AlarmIsSet=False
+
 AlarmTimeWindowStart_tuple=-1
 AlarmTimeWindowStart_seconds=-1
 
 AlarmTimeWindowEnd_tuple=-1
 AlarmTimeWindowEnd_seconds=-1
 
-#AlarmHour=-1
-#AlarmMinute=-1
-
 AlarmTimeWindow_minutes=-1
 
-Note=""
+status=""
+statusID=-1
 
+Note=""
 User=""
 SWversion=""
+
 Sampling_interval=-1
 Sample_smoothing=-1
 Value_smoothing=-1
+
 Trigger=-1
-
-
-AlarmIsSet=False
-
-status=""
-statusID=-1
\ No newline at end of file
